@@ -18,10 +18,12 @@ DTU_beamer_base = CDIR +"/DTU_Beamer_files"
 BLANK_PNG =DTU_beamer_base + "/blank.png"
 
 def ensure_dir(dname):
+    assert False
     if not os.path.exists(dname):
         os.mkdir(dname)
 
 def join_pdfs(slide_deck_pdf, outfile):
+    assert False
     dn = os.path.dirname(slide_deck_pdf[0])
     files = [os.path.relpath(os.path.dirname(pdf), start=dn) + "/" + os.path.basename(pdf) for pdf in slide_deck_pdf]
     outf = os.path.relpath(os.path.dirname(outfile), start=dn) + "/" + os.path.basename(outfile)
@@ -31,6 +33,7 @@ def join_pdfs(slide_deck_pdf, outfile):
 
 def li_import(slide_deck_pdf, tex_output_path=None, num_to_take=None, force=False, svg_pfix="osvg", svg_height=743.75, svg_width=992.5,
               svg_converted_slides="svg_converted_slides.tex"):
+    assert False
     '''
     svg_height and svg_width are used to scale the converted image. This is useful because otherwise the viewbox
     will fail to match the DTU template. I.e. these numbers will generally change dependent on the LaTeX template.
@@ -137,7 +140,7 @@ Related to li_import.
 Set the width/height of an imported slide svg image in case it does not match the DTU template. 
 '''
 def svg_set_hw_(svg_in, svg_out, height, width):
-    raise Exception("fucky..")
+    assert False
     print(f"HW fix [{height} {width}] > {svg_in} -> {svg_out}")
 
     with open(svg_in, 'r', encoding="UTF-8") as f:
@@ -167,7 +170,8 @@ def svg_set_hw_(svg_in, svg_out, height, width):
         f2.write(str(s2))
 
 def svg_check_background_layer(svg_edit_file, verbose=False):
-    return
+    assert False
+
     # Check if svg background layer is pointing to the right .png file.
     # this may not be the case sometimes because svg files are moved, etc. which overwrite the default
     # background .png path.
@@ -313,6 +317,7 @@ def add_png_background_to_svg(svg_input, png_file, svg_output=None):
 
 
 def slidedeck_to_images(slide_deck_pdf, base_out_pattern, num_to_take=None):
+    assert False
     if not os.path.exists(os.path.dirname(base_out_pattern)):
         os.mkdir(os.path.dirname(base_out_pattern))
     num_pages = num_pages_in_pdf(slide_deck_pdf)
@@ -339,6 +344,7 @@ def slidedeck_to_images(slide_deck_pdf, base_out_pattern, num_to_take=None):
     return outfiles
 
 def slidedeck_to_images_DEFUNCT(slide_deck_pdf, base_out_pattern, num_to_take=None):
+    assert False
     if not os.path.exists(os.path.dirname(base_out_pattern)):
         os.mkdir(os.path.dirname(base_out_pattern))
 
@@ -355,6 +361,7 @@ def slidedeck_to_images_DEFUNCT(slide_deck_pdf, base_out_pattern, num_to_take=No
     return outfiles
 
 def num_pages_in_pdf(pdf_file):
+    assert False
     cmd = ['pdftk', '%s' % pdf_file, 'dump_data']
     ss = execute_command(cmd)[0].splitlines()
     s = int([s for s in ss if 'NumberOfPages' in s].pop().split()[-1])
@@ -397,7 +404,9 @@ def move_template_files(output_dir="examples/output", output_tex_file=None):
     files_to_move = ["tex_dtu_logo.pdf", "tex_dtu_compute_a_uk.pdf", "tex_dtu_frise.pdf", "dtucolours.tex",
                      "beamerthemeDTU.sty", "beamerfontthemeDTU.sty","beamercolorthemeDTU.sty",
                      "beamerinnerthemeDTU.sty", "beamerouterthemeDTU.sty", "departments.tex", "tex_compute_uk.pdf",
-                     "02450_beamer_preamble.tex"]
+                     "02450_beamer_preamble.tex",  # Deprecated.
+                     'beamer_slider_preamble.tex', # The current version.
+                     ]
     sd = list( zip(files_to_move, files_to_move) )
     if output_tex_file:
         sd.append( ("02450_lectures_base.tex", output_tex_file))
@@ -416,7 +425,8 @@ def rm_svg_bg(svg_input, svg_output=None, fix_bg=True, fix_txt=True, fix_logo=Tr
     logo_rem = 0
     tx_rem = 0
     bg_rem = 0
-    if not svg_output: svg_output = svg_input
+    if not svg_output:
+        svg_output = svg_input
 
     with open(svg_input, 'r', encoding="UTF-8") as f:
         soup = BeautifulSoup(f, 'xml', from_encoding="UTF-8")
